---
height: 4
---

# Other
Global Init Scripts
- Object permissions
- Delta Live Tables
- Global Init Scripts
- Warning messages

[documentation](https://github.com/databrickslabs/ucx/blob/main/docs/assessment.md)
